@@ -238,7 +238,7 @@ class TheOneRingConnection(
 		For org.freedesktop.telepathy.Connection
 		"""
 		_moduleLogger.info("Kicking off disconnect")
-		self._delayed_disconnect()
+		self.disconnect(telepathy.CONNECTION_STATUS_REASON_REQUESTED)
 
 	@misc_utils.log_exception(_moduleLogger)
 	def RequestChannel(self, type, handleType, handleId, suppressHandler):
@@ -277,11 +277,6 @@ class TheOneRingConnection(
 
 		return props
 
-	@gobject_utils.async
-	def _delayed_disconnect(self):
-		self.disconnect(telepathy.CONNECTION_STATUS_REASON_REQUESTED)
-		return False
-
 	def disconnect(self, reason):
 		_moduleLogger.info("Disconnecting")
 
